{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_filename.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_filename.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/iaintersect:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv",
                    "id": "#iaintersect.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosome to be ignored, string\n",
                    "id": "#iaintersect.cwl/ignore_chr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input filename with MACS2 peak calling results, tsv",
                    "id": "#iaintersect.cwl/input_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#iaintersect.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#iaintersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--promoter=",
                        "separate": false
                    },
                    "doc": "Promoter region around TSS, base pairs\n",
                    "id": "#iaintersect.cwl/promoter_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--upstream=",
                        "separate": false
                    },
                    "doc": "Upstream region before promoter, base pairs\n",
                    "id": "#iaintersect.cwl/upstream_bp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_iaintersect.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_iaintersect.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/result_file"
                }
            ],
            "baseCommand": [
                "iaintersect"
            ],
            "doc": "Tool assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic)\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n",
            "id": "#iaintersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#iaintersect-metadata.yaml",
                "http://schema.org/name": "iaintersect",
                "http://schema.org/about": "Based on BioWardrobe iaintersect (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/iaintersect) The software assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic).\n",
                "http://schema.org/url": "https://github.com/Barski-lab/iaintersect/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/iaintersect",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/iaintersect/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "iaintersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/iaintersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  iaintersect [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --in                       \tInput filename with MACS2 peak calling results, xls\n  --log                      \tLog filename (default is ./logfile_def.log)\n  --out                      \tBase output file name\n  --promoter                 \tPromoter region around TSS in bp\n  --sam_ignorechr            \tThe chromosome to be ignored\n  --upstream                 \tUpstream region before promoter in bp\n"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/manorm:v0.0.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--m-cutoff"
                    },
                    "doc": "\"Absolute M-value (log2-ratio) cutoff to define biased (differential binding) peaks.\n Default: 1.0\"\n",
                    "id": "#manorm.cwl/m_value_cutoff"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--p-cutoff"
                    },
                    "doc": "\"P-value cutoff to define biased peaks.\n Default: 0.01\"\n",
                    "id": "#manorm.cwl/p_value_cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--pe"
                    },
                    "doc": "\"The middle point of each read pair is used to represent the genomic locus\nof underlying DNA fragment. --s1 and --s2 are ignored with this option on\"\n",
                    "id": "#manorm.cwl/paired_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--p1"
                    },
                    "doc": "Peaks file of sample 1",
                    "id": "#manorm.cwl/peak_file_first"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--p2"
                    },
                    "doc": "Peaks file of sample 2",
                    "id": "#manorm.cwl/peak_file_second"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#manorm.cwl/peak_format/peak_format",
                            "symbols": [
                                "#manorm.cwl/peak_format/peak_format/bed",
                                "#manorm.cwl/peak_format/peak_format/bed3-summit",
                                "#manorm.cwl/peak_format/peak_format/macs",
                                "#manorm.cwl/peak_format/peak_format/macs2",
                                "#manorm.cwl/peak_format/peak_format/narrowpeak",
                                "#manorm.cwl/peak_format/peak_format/broadpeak"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--pf"
                    },
                    "doc": "\"The format of peak files.\n Default BED\"\n",
                    "id": "#manorm.cwl/peak_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--r1"
                    },
                    "doc": "Reads file of sample 1",
                    "id": "#manorm.cwl/read_file_first"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--r2"
                    },
                    "doc": "Reads file of sample 2",
                    "id": "#manorm.cwl/read_file_second"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#manorm.cwl/read_format/read_format",
                            "symbols": [
                                "#manorm.cwl/read_format/read_format/bed",
                                "#manorm.cwl/read_format/read_format/bedpe",
                                "#manorm.cwl/read_format/read_format/sam",
                                "#manorm.cwl/read_format/read_format/bam"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--rf"
                    },
                    "doc": "\"The format of read files.\n Default BED\"\n",
                    "id": "#manorm.cwl/read_format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--n1"
                    },
                    "doc": "\"Name of sample 1, which is used in output files. If not specified, \n the name of the peak file will be used as the sample name\"\n",
                    "id": "#manorm.cwl/sample_name_first"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--n2"
                    },
                    "doc": "\"Name of sample 2, which is used in output files. If not specified,\n the name of the peak file will be used as the sample name\"\n",
                    "id": "#manorm.cwl/sample_name_second"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--s1"
                    },
                    "doc": "\"Reads shift size of sample 1. This value is used to shift reads towards 3' direction\n to determine the precise binding site. Set as half of the fragment length.\n Default 100\"\n",
                    "id": "#manorm.cwl/shift_size_first"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--s2"
                    },
                    "doc": "\"Reads shift size of sample 2. This value is used to shift reads towards 5' direction\n to determine the precise binding site. Set as half of the fragment length.\n Default 100\"\n",
                    "id": "#manorm.cwl/shift_size_second"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--n-random"
                    },
                    "doc": "\"Number of random simulations to test the enrichment of peak\n overlap between two samples. Set to 0 to disable the testing.\n Default: 10\"\n",
                    "id": "#manorm.cwl/simulations_number"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--summit-dis"
                    },
                    "doc": "\"Overlapping common peaks with summit-to-summit distance beyond this are excluded in model fitting.\nThis option is used to exclude common peaks that only overlap on the edge of each other.\nDefault: -w/--window-size/4\"\n",
                    "id": "#manorm.cwl/summit_distance"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-w"
                    },
                    "doc": "\"Window size to count reads and calculate read densities. 2000 is recommended for\nsharp histone marks like H3K4me3 and H3K27ac, and 1000 for TFs or DNase-seq.\nDefault: 2000\"\n",
                    "id": "#manorm.cwl/window_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_tracks/*_A_values.wig"
                    },
                    "doc": "Genome track file for A-values",
                    "id": "#manorm.cwl/a_values_wig_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_filters/*_M_above_*_biased_peaks.bed"
                    },
                    "doc": "Above M-value cutoff peak file",
                    "id": "#manorm.cwl/above_m_cutoff_peak_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_filters/*_M_below_*_biased_peaks.bed"
                    },
                    "doc": "Below M-value cutoff peak file",
                    "id": "#manorm.cwl/below_m_cutoff_peak_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_tracks/*_M_values.wig"
                    },
                    "doc": "Genome track file for M-values",
                    "id": "#manorm.cwl/m_values_wig_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_figures/*_MA_plot_after_normalization.*"
                    },
                    "doc": "MA-values after normalization plot",
                    "id": "#manorm.cwl/ma_after_normalization_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_figures/*_MA_plot_before_normalization.*"
                    },
                    "doc": "MA-values before normalization plot",
                    "id": "#manorm.cwl/ma_before_normalization_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_all_MAvalues.xls"
                    },
                    "doc": "\"File contains the M-A values and normalized read density of each\n peak, common peaks from two samples are merged together.\n Coordinates in .xls file is under 1-based coordinate-system\"\n",
                    "id": "#manorm.cwl/ma_values_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_figures/*_MA_plot_with_P_value.*"
                    },
                    "doc": "MA-values with P-values plot",
                    "id": "#manorm.cwl/ma_with_P_value_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_tracks/*_P_values.wig"
                    },
                    "doc": "Genome track file for P-values",
                    "id": "#manorm.cwl/p_values_wig_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_figures/*_read_density_on_common_peaks.*"
                    },
                    "doc": "Read density on common peaks plot",
                    "id": "#manorm.cwl/read_density_on_common_peaks_plot"
                },
                {
                    "type": "File",
                    "id": "#manorm.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "manorm_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#manorm.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "manorm_stdout.log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_filters/*_unbiased_peaks.bed"
                    },
                    "doc": "Unbiased peak file",
                    "id": "#manorm.cwl/unbiased_peak_file"
                }
            ],
            "baseCommand": [
                "manorm"
            ],
            "stderr": "manorm_stderr.log",
            "stdout": "manorm_stdout.log",
            "label": "MAnorm - quantitative comparison of ChIP-Seq data",
            "doc": "--wa argument is skipped\n",
            "id": "#manorm.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#manorm-metadata.yaml",
                "http://schema.org/name": "MAnorm",
                "http://schema.org/about": "MAnorm is a robust model for quantitative comparison of ChIP-Seq data sets of TFs (transcription factors) or epigenetic modifications."
            },
            "http://schema.org/name": "MAnorm - quantitative comparison of ChIP-Seq data",
            "http://schema.org/alternateName": "MAnorm is a robust model for quantitative comparison of ChIP-Seq data sets of TFs (transcription factors) or epigenetic modifications",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/manorm.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: manorm [-h] [-v] --p1 FILE --p2 FILE [--pf FORMAT] --r1 FILE --r2 FILE [--rf FORMAT] [--n1 NAME] [--n2 NAME] [--s1 N] [--s2 N] [--pe] [-w LENGTH] [--summit-dis DISTANCE]\n              [--n-random NUM] [-m FLOAT] [-p FLOAT] [-o DIR] [--wa] [--verbose]\n\nMAnorm -- A robust model for quantitative comparison of ChIP-seq data sets\n\nCitation:\n  Shao Z, Zhang Y, Yuan GC, Orkin SH, Waxman DJ. MAnorm: a robust model \n  for quantitative comparison of ChIP-Seq data sets. Genome biology. \n  2012 Mar 16;13(3):R16. https://doi.org/10.1186/gb-2012-13-3-r16\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -v, --version         show program's version number and exit\n  --verbose             Enable verbose log messages.\n\nInput Options:\n  --p1 FILE, --peak1 FILE\n                        Peak file of sample 1.\n  --p2 FILE, --peak2 FILE\n                        Peak file of sample 2.\n  --pf FORMAT, --peak-format FORMAT\n                        Format of the peak files. Support ['bed', 'bed3-summit', 'macs', 'macs2', 'narrowpeak', 'broadpeak']. Default: bed\n  --r1 FILE, --read1 FILE\n                        Read file of sample 1.\n  --r2 FILE, --read2 FILE\n                        Read file of sample 2.\n  --rf FORMAT, --read-format FORMAT\n                        Format of the read files. Support ['bed', 'bedpe', 'sam', 'bam']. Default: bed\n  --n1 NAME, --name1 NAME\n                        Name of sample 1. If not specified, the peak file name will be used.\n  --n2 NAME, --name2 NAME\n                        Name of sample 2. If not specified, the peak file name will be used.\n\nReads Manipulation:\n  --s1 N, --shiftsize1 N\n                        Single-end reads shift size for sample 1. Reads are shifted by `N` bp towards 3' direction and the 5' end of each shifted read is used to represent the\n                        genomic locus of the DNA fragment. Set to 0.5 * fragment size of the ChIP-seq library. Default: 100\n  --s2 N, --shiftsize2 N\n                        Single-end reads shift size for sample 2. Default: 100\n  --pe, --paired-end    Paired-end mode. The middle point of each read pair is used to represent the genomic locus of the DNA fragment. If specified, `--s1` and `--s2` will be\n                        ignored.\n\nNormalization Model Options:\n  -w LENGTH, --window-size LENGTH\n                        Window size to count reads and calculate read densities. Set to 2000 is recommended for sharp histone marks like H3K4me3 or H3K27ac and 1000 for TFs or\n                        DNase-seq. Default: 2000\n  --summit-dis DISTANCE\n                        Summit-to-summit distance cutoff for overlapping common peaks. Common peaks with summit distance beyond the cutoff are excluded in model fitting. Default:\n                        `window size` / 4\n  --n-random NUM        Number of random simulations to test the enrichment of peak overlap between the specified samples. Set to 0 to disable the testing. Default: 10\n\nOutput Options:\n  -m FLOAT, --m-cutoff FLOAT\n                        Absolute M-value (log2-ratio) cutoff to define the biased (differential binding) peaks. Default: 1.0\n  -p FLOAT, --p-cutoff FLOAT\n                        P-value cutoff to define the biased peaks. Default: 0.01\n  -o DIR, --output-dir DIR\n                        Output directory. Default: Current working directory\n  --wa, --write-all     Write two extra output files containing the results of the original (unmerged) peaks.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "first_chipseq_sample": [
                    "chipseq-pe.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "second_chipseq_sample": [
                    "chipseq-pe.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-pe.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": "File",
                    "label": "Annotation file",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Tab-separated annotation file\n",
                    "sd:upstreamSource": "first_chipseq_sample/genome_indices/annotation",
                    "id": "#main/annotation_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "BAM file from sample 1",
                    "doc": "BAM alignment file from sample 1\n",
                    "sd:upstreamSource": "first_chipseq_sample/bambai_pair",
                    "id": "#main/bam_file_first"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "BAM file from sample 2",
                    "doc": "BAM alignment file from sample 2\n",
                    "sd:upstreamSource": "second_chipseq_sample/bambai_pair",
                    "id": "#main/bam_file_second"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3614",
                    "label": "ChIP-Seq PE sample 1",
                    "doc": "Broad peak file from sample 1\n",
                    "sd:upstreamSource": "first_chipseq_sample/macs2_broad_peaks",
                    "sd:localLabel": true,
                    "id": "#main/broad_peak_file_first"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3614",
                    "label": "ChIP-Seq PE sample 2",
                    "doc": "Broad peak file from sample 2\n",
                    "sd:upstreamSource": "second_chipseq_sample/macs2_broad_peaks",
                    "sd:localLabel": true,
                    "id": "#main/broad_peak_file_second"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 1,
                    "label": "M-value (log2-ratio) cutoff",
                    "doc": "Absolute M-value (log2-ratio) cutoff to define biased (differential binding) peaks. Default: 1.0",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/m_value_cutoff"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.01,
                    "label": "P-value cutoff",
                    "doc": "P-value cutoff to define biased peaks. Default: 0.01",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/p_value_cutoff"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3468",
                    "label": "ChIP-Seq PE sample 1",
                    "doc": "XLS peak file from sample 1, formatted as MACS2 output\n",
                    "sd:upstreamSource": "first_chipseq_sample/macs2_called_peaks",
                    "sd:localLabel": true,
                    "id": "#main/peak_file_first"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3468",
                    "label": "ChIP-Seq PE sample 2",
                    "doc": "XLS peak file from sample 2, formatted as MACS2 output\n",
                    "sd:upstreamSource": "second_chipseq_sample/macs2_called_peaks",
                    "sd:localLabel": true,
                    "id": "#main/peak_file_second"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1000,
                    "label": "Promoter distance, bp",
                    "doc": "Max distance from gene TSS (in both direction) overlapping\nwhich the peak will be assigned to the promoter region.\nDefault: 1000 bp\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/promoter_dist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 100,
                    "label": "Reads shift size for sample 1",
                    "doc": "Reads shift size of sample 1. This value is used to shift reads towards 3' direction\nto determine the precise binding site. Set as half of the fragment length.\nDefault 100\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/shift_size_first"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 100,
                    "label": "Reads shift size for sample 2",
                    "doc": "Reads shift size of sample 2. This value is used to shift reads towards 5' direction\nto determine the precise binding site. Set as half of the fragment length.\nDefault 100\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/shift_size_second"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "label": "Upstream distance, bp",
                    "doc": "Max distance from the promoter (only in upstream direction) overlapping\nwhich the peak will be assigned to the upstream region.\nDefault: 20,000 bp\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/upstream_dist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000,
                    "label": "Window size (2000 is recommended for sharp histone marks like H3K4me3 and H3K27ac)",
                    "doc": "Window size to count reads and calculate read densities. 2000 is recommended for\nsharp histone marks like H3K4me3 and H3K27ac, and 1000 for TFs or DNase-seq.\nDefault: 2000\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/window_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Genome track file for A-values",
                    "doc": "Genome track file for A-values",
                    "outputSource": "#main/manorm/a_values_wig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/a_values_wig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/a_values_wig_file/A-values",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/a_values_wig_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Above M-value cutoff peak file",
                    "doc": "Above M-value cutoff peak file",
                    "outputSource": "#main/manorm/above_m_cutoff_peak_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/above_m_cutoff_peak_file/igvbrowser",
                                "type": "annotation",
                                "name": "#main/above_m_cutoff_peak_file/Above M-value cutoff peaks",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/above_m_cutoff_peak_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Below M-value cutoff peak file",
                    "doc": "Below M-value cutoff peak file",
                    "outputSource": "#main/manorm/below_m_cutoff_peak_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/below_m_cutoff_peak_file/igvbrowser",
                                "type": "annotation",
                                "name": "#main/below_m_cutoff_peak_file/Below M-value cutoff peaks",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/below_m_cutoff_peak_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "MAnorm common peak file with assigned genes",
                    "doc": "\"File contains nearest gene information, the M-A values and normalized read\n density of each peak, common peaks from two samples are merged together.\n Coordinates in a result file is under 1-based coordinate-system\"\n",
                    "outputSource": "#main/restore_columns/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Differential Peak Calling",
                                "Title": "MAnorm Common Peak Results"
                            }
                        }
                    ],
                    "id": "#main/common_peak_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Genome track file for M-values",
                    "doc": "Genome track file for M-values",
                    "outputSource": "#main/manorm/m_values_wig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/m_values_wig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/m_values_wig_file/M-values",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/m_values_wig_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3603",
                    "label": "MA-values after normalization plot",
                    "doc": "MA-values after normalization plot",
                    "outputSource": "#main/manorm/ma_after_normalization_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "MA-values after normalization"
                            }
                        }
                    ],
                    "id": "#main/ma_after_normalization_plot"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3603",
                    "label": "MA-values before normalization plot",
                    "doc": "MA-values before normalization plot",
                    "outputSource": "#main/manorm/ma_before_normalization_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "MA-values before normalization"
                            }
                        }
                    ],
                    "id": "#main/ma_before_normalization_plot"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3603",
                    "label": "MA-values with P-values plot",
                    "doc": "MA-values with P-values plot",
                    "outputSource": "#main/manorm/ma_with_P_value_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "MA-values with P-values"
                            }
                        }
                    ],
                    "id": "#main/ma_with_P_value_plot"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "MAnorm stderr log",
                    "doc": "MAnorm stderr log",
                    "outputSource": "#main/manorm/stderr_log",
                    "id": "#main/manorm_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "MAnorm stdout log",
                    "doc": "MAnorm stdout log",
                    "outputSource": "#main/manorm/stdout_log",
                    "id": "#main/manorm_stdout_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Genome track file for P-values",
                    "doc": "Genome track file for P-values",
                    "outputSource": "#main/manorm/p_values_wig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/p_values_wig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/p_values_wig_file/P-values",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/p_values_wig_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3603",
                    "label": "Read density on common peaks plot",
                    "doc": "Read density on common peaks plot",
                    "outputSource": "#main/manorm/read_density_on_common_peaks_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Read density on common peaks"
                            }
                        }
                    ],
                    "id": "#main/read_density_on_common_peaks_plot"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Unbiased peak file",
                    "doc": "Unbiased peak file",
                    "outputSource": "#main/manorm/unbiased_peak_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/unbiased_peak_file/igvbrowser",
                                "type": "annotation",
                                "name": "#main/unbiased_peak_file/Unbiased peaks",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/unbiased_peak_file"
                }
            ],
            "steps": [
                {
                    "run": "#iaintersect.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/assign_genes/annotation_filename"
                        },
                        {
                            "source": "#main/filter_columns/output_file",
                            "id": "#main/assign_genes/input_filename"
                        },
                        {
                            "source": "#main/promoter_dist",
                            "id": "#main/assign_genes/promoter_bp"
                        },
                        {
                            "source": "#main/upstream_dist",
                            "id": "#main/assign_genes/upstream_bp"
                        }
                    ],
                    "out": [
                        "#main/assign_genes/result_file"
                    ],
                    "id": "#main/assign_genes"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/manorm/ma_values_file",
                            "id": "#main/filter_columns/input_file"
                        },
                        {
                            "default": "cat $0 | grep -v \"start\" | awk 'BEGIN {print \"chr\\tstart\\tend\\tlength\\tabs_summit\\tpileup\\t-log10(pvalue)\\tfold_enrichment\\t-log10(qvalue)\\tname\"} {print $1\"\\t\"$2\"\\t\"$3\"\\t\"$3-$2+1\"\\t0\\t\"NR\"\\t0\\t0\\t0\\t0\"}' > `basename $0`\n",
                            "id": "#main/filter_columns/script"
                        }
                    ],
                    "out": [
                        "#main/filter_columns/output_file"
                    ],
                    "id": "#main/filter_columns"
                },
                {
                    "run": "#manorm.cwl",
                    "in": [
                        {
                            "source": "#main/m_value_cutoff",
                            "id": "#main/manorm/m_value_cutoff"
                        },
                        {
                            "source": "#main/p_value_cutoff",
                            "id": "#main/manorm/p_value_cutoff"
                        },
                        {
                            "default": true,
                            "id": "#main/manorm/paired_end"
                        },
                        {
                            "source": [
                                "#main/peak_file_first",
                                "#main/peak_file_second",
                                "#main/broad_peak_file_first",
                                "#main/broad_peak_file_second"
                            ],
                            "valueFrom": "${\n  if (self[2] && self[3]){\n    return self[2];\n  }\n  else {\n    return self[0];\n  }\n}\n",
                            "id": "#main/manorm/peak_file_first"
                        },
                        {
                            "source": [
                                "#main/peak_file_first",
                                "#main/peak_file_second",
                                "#main/broad_peak_file_first",
                                "#main/broad_peak_file_second"
                            ],
                            "valueFrom": "${\n  if (self[2] && self[3]){\n    return self[3];\n  }\n  else {\n    return self[1];\n  }\n}\n",
                            "id": "#main/manorm/peak_file_second"
                        },
                        {
                            "source": [
                                "#main/peak_file_first",
                                "#main/peak_file_second",
                                "#main/broad_peak_file_first",
                                "#main/broad_peak_file_second"
                            ],
                            "valueFrom": "${\n  if (self[2] && self[3]){\n    return \"broadpeak\";\n  }\n  else {\n    return \"macs2\";\n  }\n}\n",
                            "id": "#main/manorm/peak_format"
                        },
                        {
                            "source": "#main/bam_file_first",
                            "id": "#main/manorm/read_file_first"
                        },
                        {
                            "source": "#main/bam_file_second",
                            "id": "#main/manorm/read_file_second"
                        },
                        {
                            "default": "bam",
                            "id": "#main/manorm/read_format"
                        },
                        {
                            "default": "sample_1",
                            "id": "#main/manorm/sample_name_first"
                        },
                        {
                            "default": "sample_2",
                            "id": "#main/manorm/sample_name_second"
                        },
                        {
                            "source": "#main/shift_size_first",
                            "id": "#main/manorm/shift_size_first"
                        },
                        {
                            "source": "#main/shift_size_second",
                            "id": "#main/manorm/shift_size_second"
                        },
                        {
                            "source": "#main/window_size",
                            "id": "#main/manorm/window_size"
                        }
                    ],
                    "out": [
                        "#main/manorm/ma_values_file",
                        "#main/manorm/above_m_cutoff_peak_file",
                        "#main/manorm/below_m_cutoff_peak_file",
                        "#main/manorm/unbiased_peak_file",
                        "#main/manorm/m_values_wig_file",
                        "#main/manorm/a_values_wig_file",
                        "#main/manorm/p_values_wig_file",
                        "#main/manorm/ma_before_normalization_plot",
                        "#main/manorm/ma_after_normalization_plot",
                        "#main/manorm/ma_with_P_value_plot",
                        "#main/manorm/read_density_on_common_peaks_plot",
                        "#main/manorm/stderr_log",
                        "#main/manorm/stdout_log"
                    ],
                    "id": "#main/manorm"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/assign_genes/result_file",
                                "#main/manorm/ma_values_file"
                            ],
                            "id": "#main/restore_columns/input_file"
                        },
                        {
                            "default": "cat $0 | grep -v \"start\" | sort -k 11n > sorted_iaintersect_result.tsv\ncat $1 | grep -v \"start\" > manorm_result.tsv\necho -e \"refseq_id\\tgene_id\\ttxStart\\ttxEnd\\tstrand\\tchrom\\tstart\\tend\\tlength\\tregion\\tsummit\\tM_value\\tA_value\\tP_value\\tPeak_Group\\tnormalized_read_density_in_sample_1\\tnormalized_read_density_in_sample_2\" > `basename $0`;\ncat sorted_iaintersect_result.tsv | paste - manorm_result.tsv | cut -f 1-9,15,19-25 >> `basename $0`\nrm sorted_iaintersect_result.tsv manorm_result.tsv\n",
                            "id": "#main/restore_columns/script"
                        }
                    ],
                    "out": [
                        "#main/restore_columns/output_file"
                    ],
                    "id": "#main/restore_columns"
                }
            ],
            "label": "MAnorm PE - quantitative comparison of ChIP-Seq paired-end data",
            "doc": "What is MAnorm?\n--------------\n\nMAnorm is a robust model for quantitative comparison of ChIP-Seq data sets of TFs (transcription factors) or epigenetic modifications and you can use it for:\n\n* Normalization of two ChIP-seq samples\n* Quantitative comparison (differential analysis) of two ChIP-seq samples\n* Evaluating the overlap enrichment of the protein binding sites(peaks)\n* Elucidating underlying mechanisms of cell-type specific gene regulation\n\nHow MAnorm works?\n----------------\n\nMAnorm uses common peaks of two samples as a reference to build the rescaling model for normalization, which is based on the empirical assumption that if a chromatin-associated protein has a substantial number of peaks shared in two conditions, the binding at these common regions will tend to be determined by similar mechanisms, and thus should exhibit similar global binding intensities across samples. The observed differences on common peaks are presumed to reflect the scaling relationship of ChIP-Seq signals between two samples, which can be applied to all peaks.\n\nWhat do the inputs mean?\n----------------\n\n### General\n\n**Experiment short name/Alias**\n\n* short name for you experiment to identify among the others\n\n**ChIP-Seq PE sample 1**\n* previously analyzed ChIP-Seq paired-end experiment to be used as Sample 1\n\n**ChIP-Seq PE sample 2**\n\n* previously analyzed ChIP-Seq paired-end experiment to be used as Sample 2\n\n**Genome**\n\n* Reference genome to be used for gene assigning\n\n### Advanced\n\n**Reads shift size for sample 1**\n\n* This value is used to shift reads towards 3' direction to determine\n  the precise binding site. Set as half of the fragment length. Default 100\n\n**Reads shift size for sample 2**\n\n* This value is used to shift reads towards 5' direction to determine\n  the precise binding site. Set as half of the fragment length. Default 100\n\n**M-value (log2-ratio) cutoff**\n\n* Absolute M-value (log2-ratio) cutoff to define biased (differential binding)\n  peaks. Default: 1.0\n\n**P-value cutoff**\n\n* P-value cutoff to define biased peaks. Default: 0.01\n\n**Window size**\n\n* Window size to count reads and calculate read densities. 2000 is recommended for\n  sharp histone marks like H3K4me3 and H3K27ac, and 1000 for TFs or DNase-seq.\n  Default: 2000",
            "id": "#main",
            "http://schema.org/name": "MAnorm PE - quantitative comparison of ChIP-Seq paired-end data",
            "http://schema.org/alternateName": "MAnorm is a robust model for quantitative comparison of ChIP-Seq paired-end data sets of TFs (transcription factors) or epigenetic modifications",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/manorm-pe.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
